pub struct AudioSampleRates(/* private fields */);Expand description
Sample-rate support mask from byte 2 of a Short Audio Descriptor.
Each set bit indicates the display/sink supports that sample rate.
Implementations
Sourceimpl AudioSampleRates
impl AudioSampleRates
Sourcepub const HZ_32000: AudioSampleRates
pub const HZ_32000: AudioSampleRates
32 kHz sample rate.
Sourcepub const HZ_44100: AudioSampleRates
pub const HZ_44100: AudioSampleRates
44.1 kHz sample rate.
Sourcepub const HZ_48000: AudioSampleRates
pub const HZ_48000: AudioSampleRates
48 kHz sample rate.
Sourcepub const HZ_88200: AudioSampleRates
pub const HZ_88200: AudioSampleRates
88.2 kHz sample rate.
Sourcepub const HZ_96000: AudioSampleRates
pub const HZ_96000: AudioSampleRates
96 kHz sample rate.
Sourcepub const HZ_176400: AudioSampleRates
pub const HZ_176400: AudioSampleRates
176.4 kHz sample rate.
Sourcepub const HZ_192000: AudioSampleRates
pub const HZ_192000: AudioSampleRates
192 kHz sample rate.
Sourceimpl AudioSampleRates
impl AudioSampleRates
Sourcepub const fn empty() -> AudioSampleRates
pub const fn empty() -> AudioSampleRates
Get a flags value with all bits unset.
Sourcepub const fn all() -> AudioSampleRates
pub const fn all() -> AudioSampleRates
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<AudioSampleRates>
pub const fn from_bits(bits: u8) -> Option<AudioSampleRates>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> AudioSampleRates
pub const fn from_bits_truncate(bits: u8) -> AudioSampleRates
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> AudioSampleRates
pub const fn from_bits_retain(bits: u8) -> AudioSampleRates
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<AudioSampleRates>
pub fn from_name(name: &str) -> Option<AudioSampleRates>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: AudioSampleRates) -> bool
pub const fn intersects(&self, other: AudioSampleRates) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: AudioSampleRates) -> bool
pub const fn contains(&self, other: AudioSampleRates) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: AudioSampleRates)
pub fn insert(&mut self, other: AudioSampleRates)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: AudioSampleRates)
pub fn remove(&mut self, other: AudioSampleRates)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: AudioSampleRates)
pub fn toggle(&mut self, other: AudioSampleRates)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: AudioSampleRates, value: bool)
pub fn set(&mut self, other: AudioSampleRates, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: AudioSampleRates) -> AudioSampleRates
pub const fn intersection(self, other: AudioSampleRates) -> AudioSampleRates
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: AudioSampleRates) -> AudioSampleRates
pub const fn union(self, other: AudioSampleRates) -> AudioSampleRates
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: AudioSampleRates) -> AudioSampleRates
pub const fn difference(self, other: AudioSampleRates) -> AudioSampleRates
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: AudioSampleRates,
) -> AudioSampleRates
pub const fn symmetric_difference( self, other: AudioSampleRates, ) -> AudioSampleRates
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> AudioSampleRates
pub const fn complement(self) -> AudioSampleRates
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl AudioSampleRates
impl AudioSampleRates
Sourcepub const fn iter(&self) -> Iter<AudioSampleRates>
pub const fn iter(&self) -> Iter<AudioSampleRates>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<AudioSampleRates>
pub const fn iter_names(&self) -> IterNames<AudioSampleRates>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.